@@ -180,7 +180,13 @@ class WialonBase:
             )
         else:
             self.session.wialon_api.item_update_admin_field(
-                **{"itemId": self.id, "callMode": "create", "n": key, "v": value}
+                **{
+                    "itemId": self.id,
+                    "id": 0,
+                    "callMode": "create",
+                    "n": key,
+                    "v": value,
+                }
             )
 
     def update_cfield(self, key: str, value: str) -> None:
@@ -208,6 +214,7 @@ class WialonBase:
             )
 
         field_id: int | None = self._get_cfield_id(key)
+        print(f"{field_id = }")
         if field_id is not None:
             self.session.wialon_api.item_update_custom_field(
                 **{
@@ -220,7 +227,13 @@ class WialonBase:
             )
         else:
             self.session.wialon_api.item_update_custom_field(
-                **{"itemId": self.id, "callMode": "create", "n": key, "v": value}
+                **{
+                    "itemId": self.id,
+                    "id": 0,
+                    "callMode": "create",
+                    "n": key,
+                    "v": value,
+                }
             )
 
     def _get_cfield_id(self, key: str) -> int | None:
@@ -322,13 +335,10 @@ class WialonBase:
         :type: :py:obj:`dict`
 
         """
-        print(f"Retrieving cfields for {self.id}...")
         response = self.session.wialon_api.core_search_item(
             **{"id": self.id, "flags": flags.DataFlag.UNIT_ADMIN_FIELDS}
         )
-        print(f"{response = }")
         fields = response.get("item", {}).get("aflds") if response is not None else {}
-        print(f"{fields = }")
         return {field["n"]: field["v"] for field in fields.values()} if fields else {}
 
     @property
@@ -339,13 +349,10 @@ class WialonBase:
         :type: :py:obj:`dict`
 
         """
-        print(f"Retrieving cfields for {self.id}...")
         response = self.session.wialon_api.core_search_item(
             **{"id": self.id, "flags": flags.DataFlag.UNIT_CUSTOM_FIELDS}
         )
-        print(f"{response = }")
         fields = response.get("item", {}).get("flds") if response is not None else {}
-        print(f"{fields = }")
         return {field["n"]: field["v"] for field in fields.values()} if fields else {}
 
     @property
